@@ -197,7 +197,7 @@ class TimestreamLoader(TimestreamReader):
             )
         except ClientError as e:
             self._logger.error(f'Failed to write insert records: {e}')
-            accepted_records, rejected_records = self.__process_client_error(e, records)
+            accepted_records, rejected_records = self.__process_client_error(e, records, is_multi)
         return accepted_records, rejected_records
 
     def __write_upsert_records(
@@ -230,7 +230,7 @@ class TimestreamLoader(TimestreamReader):
             )
         except ClientError as e:
             self._logger.error(f'Failed to write upsert records: {e}')
-            accepted_records, rejected_records = self.__process_client_error(e, records)
+            accepted_records, rejected_records = self.__process_client_error(e, records, is_multi)
         return accepted_records, rejected_records
 
     def __process_client_error(self, e: ClientError, records: List[dict], is_multi: bool = False) -> tuple:
